@@ -136,6 +136,17 @@ void CrossMap( SimplexClass   & S,
         throw std::runtime_error( errMsg.str() );
     }
 
+    if ( S.parameters.Tp < 0 and
+         (int) S.data.NRows() + S.parameters.Tp <=
+         (int) S.parameters.librarySizes.back() ) {
+        std::lock_guard<std::mutex> lck( EDM_CCM_Lock::mtx );
+        std::stringstream errMsg;
+        errMsg << "CrossMap(): Tp = " << S.parameters.Tp
+               << " is inconsistent with maximum libSize = "
+               << S.parameters.librarySizes.back();
+        throw std::runtime_error( errMsg.str() );
+    }
+
     // Note that the embedding has NPartial invalid rows
     // since partial data vectors were not removed.
     size_t N_row = S.embedding.NRows() - NPartial;
